from distutils.core import setup

setup(
    name = 'surgeon',
    packages = ['surgeon'],
    version = '0.1',
    description = 'A random find/replace library',
    author = 'Alexander Ivanov',
    author_email = 'alehander42@gmail.com',
    url = 'https://github.com/alehander42/python-surgeon',
    keywords = ['search', 'replace', 'syntax'],
    classifiers = [],
)